.. image:: https://coveralls.io/repos/github/VSPEC-collab/vspec-vsm/badge.svg
    :target: https://coveralls.io/github/VSPEC-collab/vspec-vsm

.. image:: https://github.com/VSPEC-collab/vspec-vsm/actions/workflows/python-package-conda.yml/badge.svg
    :target: https://github.com/VSPEC-collab/vspec-vsm/actions/workflows/python-package-conda.yml

.. image:: https://readthedocs.org/projects/vspec-vsm/badge/?version=latest
    :target: https://vspec-vsm.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status


VSPEC Variable Star Model
=========================

The Variable Star Model from VSPEC as a
stand-alone package.

Installation
------------

Type ``pip install vspec-vsm`` in your terminal to install
the package in your environment.

Docs
----

See the docs at `https://vspec-vsm.readthedocs.io <https://vspec-vsm.readthedocs.io>`_